@@ -124,9 +124,45 @@ qx.Class.define('callbackery.ui.plugin.Table', {
                 if ('visible' in col) {
                     tcm.setColumnVisible(i, col.visible);
                 }
-                if (col.width != null) {
-                    resizeBehavior.setWidth(i, String(col.width));
+            });
+
+            let setColumnResizeBehavior = () => {
+                let flexList = [];
+                let totalFlex = 0;
+                cfg.table.forEach((col, i) => {
+                    if (tcm.isColumnVisible(i) && col.width) {
+                        let match = String(col.width).match(/^(\d+)\*/);
+                        if (match) {
+                            let flex = parseInt(match[1]);
+                            totalFlex += flex;
+                            flexList[i] = flex;
+                        }
+                    }
+                });
+                let width = this.getBounds().width;
+                let cols = tcm.getVisibleColumnCount();
+                if (width / cols < 100) {
+                    let oneFlex = cols * 100 / totalFlex;
+                    cfg.table.forEach((col, i) => {
+                        if (flexList[i]) {
+                            resizeBehavior.setWidth(i, Math.round(oneFlex * flexList[i]));
+                        }
+                    });
                 }
+                else {
+                    cfg.table.forEach((col, i) => {
+                        if (col.width) {
+                            resizeBehavior.setWidth(i, col.width);
+                        }
+                    });
+                }
+            };
+            this.addListener('resize', () => {
+                setColumnResizeBehavior();
+            });
+
+            table.addListener('columnVisibilityChanged', () => {
+                setColumnResizeBehavior();
             });
 
             var selectionModel = table.getSelectionModel();
